define(["angular", "tool"], function() {
    "use strict";
    return angular.module("ums-award", [])
        .directive("umsAward", ["$animate", "$timeout", function($animate, $timeout) {
            function link(scope, elem, attrs, ctrl) {
                var openAudio = elem.children().eq(4).children().eq(0)[0];
                var rebateAudio = elem.children().eq(4).children().eq(1)[0];

                document.addEventListener("award-start", function(event) {
                    scope.$apply(function() {
                        scope.model.onShake();
                    });
                });

                document.addEventListener("award-end", function(event) {
                    rebateAudio.play();
                });

                var upper = elem.children().eq(0);
                var lower = elem.children().eq(2);

                var open = function () {
                    $animate.addClass(upper, "ums-award-upper-up", null);
                    $animate.addClass(lower, "ums-award-lower-down", null);
                };

                var close = function () {
                    $animate.addClass(upper, "ums-award-upper-normal", null);
                    $animate.addClass(lower, "ums-award-lower-normal", null);
                };

                scope.model.onShake = scope.model.onShake || function() {
                    if (!scope.model.isShaking) {
                        scope.model.isShaking = true;

                        openAudio.play();

                        open();

                        if (!Tools.data.check.isEmpty(scope.model.onShakeAppend)) {
                            scope.model.onShakeAppend();
                        }

                        $timeout(close, 600);
                    }
                };

                scope.model.onResultButtonClick = scope.model.onResultButtonClick || function() {
                    // 清除添加的样式
                    $animate.removeClass(upper, "ums-award-upper-up", null);
                    $animate.removeClass(lower, "ums-award-lower-down", null);

                    $animate.removeClass(upper, "ums-award-upper-normal", null);
                    $animate.removeClass(lower, "ums-award-lower-normal", null);

                    // 隐藏摇奖结果展示DIV
                    scope.model.resultShow = false;

                    // 清除resultInfo
                    scope.model.resultInfo = ["", ""];

                    // 清除resultButtonText
                    scope.model.resultButtonText = "";

                    if (!Tools.data.check.isEmpty(scope.model.onResultButtonClickAppend)) {
                        scope.model.onResultButtonClickAppend();
                    }
                };
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-award">'
                        +     '<div class="ums-award-upper" ng-click="model.onShake();">'
                        +         '<span>今天还有<span ng-bind="model.unusedShakeTimes"></span>次摇奖机会</span>'
                        +         '<img src="images/img_upper_half.png">'
                        +     '</div>'
                        +     '<div class="ums-award-list"></div>'
                        +     '<div class="ums-award-lower" ng-click="model.onShake();">'
                        +         '<span ng-show="!model.resultShow"></span>'
                        +         '<img src="images/img_lower_half.png">'
                        +     '</div>'
                        +     '<div class="ums-award-result" ng-show="model.resultShow">'
                        +         '<div class="ums-award-result-img">'
                        +             '<img src="images/{{model.resultImg}}">'
                        +         '</div>'
                        +         '<div class="ums-award-result-info">'
                        +             '<span ng-bind="model.resultInfo[0]"></span>'
                        +             '<span ng-bind="model.resultInfo[1]"></span>'
                        +         '</div>'
                        +         '<div class="ums-award-result-button">'
                        +             '<span ng-click="model.onResultButtonClick();" ng-bind="model.resultButtonText">'
                        +             '</span>'
                        +         '</div>'
                        +     '</div>'
                        +     '<div class="ums-award-audios">'
                        +         '<audio src="audios/open.mp3" controls="controls"></audio>'
                        +         '<audio src="audios/rebate.mp3" controls="controls"></audio>'
                        +     '</div>'
                        + '</div>',
                link: link
            };
        }]);
});