define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-checkout-stand", [])
        .directive("umsCheckoutStand", function() {
            function link(scope, elem, attrs, ctrl) {
                // 是否第一次按键
                var firstClick = true;

                scope.onDigitKeyClick = function(digit) {
                    if (!firstClick) {
                        // 小数点显示时
                        if (scope.values.dotShow) {
                            // 小数部分不超过2位
                            if (scope.values.decPart.length < 2) {
                                scope.values.decPart += digit;
                            }
                        } else {
                            // 如果整数部分等于0
                            if (scope.values.intPart == "0") {
                                // 再输入0, 直接返回
                                if (digit == "0") return;

                                // 整数部分等于输入的数字
                                scope.values.intPart = digit;
                            } else if (scope.values.intPart.length < 6) {
                                // 整数部分不超过6位
                                scope.values.intPart += digit;
                            }
                        }
                    } else {
                        firstClick = false;

                        scope.values.intPart = digit;
                        scope.values.decPart = "";
                        scope.values.dotShow = false;
                    }
                };

                scope.onDotKeyClick = function() {
                    // 小数点隐藏且整数部分不为空时, 显示小数点
                    if (!scope.values.dotShow && scope.values.intPart !== "") {
                        scope.values.dotShow = true;
                    }
                };

                scope.onBackspaceKeyClick = function() {
                    if (scope.values.decPart.length != 0) {
                        // 小数部分长度不为0时, 则将其长度减1
                        scope.values.decPart = scope.values.decPart.substring(0, scope.values.decPart.length - 1);

                        // 小数部分长度为0时, 隐藏小数点
                        if (scope.values.decPart.length == 0) {
                            scope.values.dotShow = false;
                        }
                    } else if (scope.values.dotShow) {
                        // 小数部分长度为0且小数点显示时, 隐藏小数点
                        scope.values.dotShow = false;
                    } else if (scope.values.intPart.length != 0) {
                        // 小数部分长度为0、小数点隐藏且整数部分长度不为0时, 将整数部分的长度减1
                        scope.values.intPart = scope.values.intPart.substring(0, scope.values.intPart.length - 1);
                    }
                };

                scope.values = {
                    // 整数部分
                    intPart: "0",
                    // 小数点是否显示
                    dotShow: true,
                    // 小数部分
                    decPart: "00"
                };

                scope.model.onCheckoutButtonClick = scope.model.onCheckoutButtonClick || function() {
                    if (!Tools.data.check.isEmpty(scope.model.onCheckoutButtonClickAppend)) {
                        scope.model.onCheckoutButtonClickAppend();
                    }
                };

                scope.$watch("values", function(newValue) {
                    scope.model.value = scope.values.intPart;

                    if (scope.values.decPart != "") {
                        scope.model.value += "." + scope.values.decPart;
                    }
                }, true);
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-checkout-stand">'
                        +     '<div class="ums-checkout-stand-header">'
                        +         '<span class="dec" ng-bind="values.decPart"></span>'
                        +         '<span class="dot" ng-show="values.dotShow">.</span>'
                        +         '<span class="int" ng-bind="values.intPart"></span>'
                        +         '<span class="yuan">￥</span>'
                        +     '</div>'
                        +     '<div class="ums-checkout-stand-body">'
                        +         '<div class="ums-checkout-stand-keys">'
                        +             '<span ng-click="onDigitKeyClick(\'1\');">'
                        +                 '<span>1</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'2\');">'
                        +                 '<span>2</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'3\');">'
                        +                 '<span>3</span>'
                        +             '</span>'
                        +         '</div>'
                        +         '<div class="ums-checkout-stand-keys">'
                        +             '<span ng-click="onDigitKeyClick(\'4\');">'
                        +                 '<span>4</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'5\');">'
                        +                 '<span>5</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'6\');">'
                        +                 '<span>6</span>'
                        +             '</span>'
                        +         '</div>'
                        +         '<div class="ums-checkout-stand-keys">'
                        +             '<span ng-click="onDigitKeyClick(\'7\');">'
                        +                 '<span>7</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'8\');">'
                        +                 '<span>8</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'9\');">'
                        +                 '<span>9</span>'
                        +             '</span>'
                        +         '</div>'
                        +         '<div class="ums-checkout-stand-keys">'
                        +             '<span ng-click="onDotKeyClick();">'
                        +                 '<span>.</span>'
                        +             '</span>'
                        +             '<span ng-click="onDigitKeyClick(\'0\');">'
                        +                 '<span>0</span>'
                        +             '</span>'
                        +             '<span ng-click="onBackspaceKeyClick();">'
                        +                 '<span class="backspace-key">&nbsp;</span>'
                        +             '</span>'
                        +         '</div>'
                        +     '</div>'
                        +     '<div class="ums-checkout-stand-footer" '
                        +         'ng-click="model.onCheckoutButtonClick();">'
                        +         '<span>确认收款</span>'
                        +     '</div>'
                        + '</div>',
                link: link
            };
        });
});