define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-input", [])
        .directive("umsInput", ["$compile", function($compile) {
            function link(scope, elem, attrs, ctrl) {
                var typeOfInput = "text";

                // 是否为页面中的第一个元素
                var isTop = false;
                
                if (!Tools.data.check.isEmpty(attrs.isTop)) {
                    if (typeof(attrs.isTop) == "string") {
                    	isTop = (attrs.isTop == "true") || !(attrs.isTop == "false");
                    } else if (typeof(attrs.isTop) == "boolean") {
                    	isTop = attrs.isTop;
                    }
                } else {
                    if (typeof(scope.model.isTop) == "string") {
                    	isTop = (scope.model.isTop == "true") || !(scope.model.isTop == "false");
                    } else if (typeof(scope.model.isTop) == "boolean") {
                    	isTop = scope.model.isTop;
                    }
                }
                
                // 输入类型
                var inputType = attrs.inputType || scope.model.inputType;
                // 文本的最大长度
                var maxLength = attrs.maxLength || scope.model.maxLength;
                // 整数部分的最大长度
                var intLength = attrs.intLength || scope.model.intLength;
                // 小数部分的最大长度
                var decLength = attrs.decLength || scope.model.decLength;
                // 分隔长度
                var splitLength = attrs.splitLength || scope.model.splitLength;
                var firstSplitLength = attrs.firstSplitLength || scope.model.firstSplitLength;

                scope.model.inputTitle = attrs.inputTitle || scope.model.inputTitle;
                scope.model.inputLabel = attrs.inputLabel || scope.model.inputLabel;
                scope.model.placeHolder = attrs.placeHolder || scope.model.placeHolder;
                scope.model.tips = attrs.tips || scope.model.tips;
                scope.model.chooseIconType = attrs.chooseIconType || scope.model.chooseIconType;
                scope.model.inputFootText = attrs.inputFootText || scope.model.inputFootText;

                // inputTitle不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputTitle)) {
                    scope.inputTitleShow = true;
                }
                
                // 页面中的第一个元素, 而且title不为空, 则将margin-top设为0
                if (isTop && scope.inputTitleShow) {
                	scope.marginTop = "margin-top-0";
                }

                // inputLabel不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputLabel)) {
                    scope.inputLabelShow = true;
                }

                // 根据chooseIconType显示不同的icon
                if (scope.model.chooseIconType == "camera") {
                    scope.chooseIconShow = true;
                    scope.chooseIconClass = "ums-input-choose-camera";
                } else if (scope.model.chooseIconType == "card") {
                    scope.chooseIconShow = true;
                    scope.chooseIconClass = "ums-input-choose-card";
                } else if (scope.model.chooseIconType == "note") {
                    scope.chooseIconShow = true;
                    scope.chooseIconClass = "ums-input-choose-note";
                } else if (scope.model.chooseIconType == "reminder") {
                    scope.chooseIconShow = true;
                    scope.chooseIconClass = "ums-input-choose-reminder";
                } else {
                    scope.chooseIconShow = false;
                }

                // inputFootText不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputFootText)) {
                    scope.inputFootTextShow = true;
                }

                scope.model.inputOnBlur = scope.model.inputOnBlur || function() {
                        scope.clearIconClass = "";
                    if (!Tools.data.check.isEmpty(scope.model.value)) {
                        if (inputType == "integer") {
                            scope.model.value = Tools.data.format.stringWithSpace(
                                scope.model.value, splitLength, firstSplitLength);
                        } else if (inputType == "decimal") {
                            if (!isNaN(scope.model.value)) {
                                scope.model.value = Tools.data.format.decimal(scope.model.value);
                            }
                        } else if (inputType == "money") {
                            if (!isNaN(scope.model.value)) {
                                scope.model.value = Tools.data.format.money(scope.model.value);
                            }
                        }
                    }
//                    scope.clearIconClass = "";
                    if (!Tools.data.check.isEmpty(scope.model.inputOnBlurAppend)) {
                        scope.model.inputOnBlurAppend();
                    }
                };

                scope.model.inputOnFocus = scope.model.inputOnFocus || function() {
                    scope.model.value = Tools.data.convert.trim(scope.model.value);
                    if (!Tools.data.check.isEmpty(scope.model.value)) {
                        // input不为空, 则显示clearIcon
                        scope.clearIconClass = "ums-input-clear-icon";
                    } else {
                        // input为空, 则不显示clearIcon
                        scope.clearIconClass = "";
                    }
                    if (!Tools.data.check.isEmpty(scope.model.inputOnFocusAppend)) {
                        scope.model.inputOnFocusAppend();
                    }
                };

                scope.model.inputOnKeyUp = scope.model.inputOnKeyUp || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnKeyUpAppend)) {
                        scope.model.inputOnKeyUpAppend();
                    }
                };

                if (inputType == "integer") {
                    typeOfInput = "tel";
                }
                if (inputType == "password") {
                    typeOfInput = "password";
                }
                
                if (inputType == "text" || inputType == "integer"|| inputType == "password") {
                    scope.model.inputOnKeyPress = scope.model.inputOnKeyPress || function() {
                        if (!Tools.data.check.isEmpty(scope.model.inputOnKeyPressAppend)) {
                            scope.model.inputOnKeyPressAppend();
                        }
                    };
                } else if (inputType == "decimal" || inputType == "money") {
                	scope.model.inputOnKeyPress = scope.model.inputOnKeyPress || function(event) {
                        event = event || window.event;

                        var keyCode = event.keyCode || event.which;

                        if ((keyCode >= 48 && keyCode <= 57) || keyCode == 46) {
                            event.returnValue = true;
                        } else {
                            event.returnValue = false;
                        }
                        
                        if (!Tools.data.check.isEmpty(scope.model.inputOnKeyPressAppend)) {
                            scope.model.inputOnKeyPressAppend();
                        }
                    };
                }

                if (inputType == "text"|| inputType == "password") {
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2StringWithLength(
                            scope.model.value, maxLength);
                        if (!Tools.data.check.isEmpty(scope.model.value)) {
                            // input不为空, 则显示clearIcon
                            scope.clearIconClass = "ums-input-clear-icon";
                        } else {
                            // input为空, 则不显示clearIcon
                            scope.clearIconClass = "";
                        }
                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                } else if (inputType == "integer") {
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2IntegerWithLength(
                            scope.model.value, intLength);
                        if (!Tools.data.check.isEmpty(scope.model.value)) {
                            // input不为空, 则显示clearIcon
                            scope.clearIconClass = "ums-input-clear-icon";
                        } else {
                            // input为空, 则不显示clearIcon
                            scope.clearIconClass = "";
                        }
                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                } else if (inputType == "decimal") {
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2Decimal(
                            scope.model.value, intLength, decLength);
                        if (!Tools.data.check.isEmpty(scope.model.value)) {
                            // input不为空, 则显示clearIcon
                            scope.clearIconClass = "ums-input-clear-icon";
                        } else {
                            // input为空, 则不显示clearIcon
                            scope.clearIconClass = "";
                        }
                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                } else if (inputType == "money") {
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2Money(scope.model.value);
                        if (!Tools.data.check.isEmpty(scope.model.value)) {
                            // input不为空, 则显示clearIcon
                            scope.clearIconClass = "ums-input-clear-icon";
                        } else {
                            // input为空, 则不显示clearIcon
                            scope.clearIconClass = "";
                        }
                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                }

                scope.model.inputOnClear = scope.model.inputOnClear || function() {
                    scope.model.value = "";
                    scope.clearIconClass = "";
                    if (!Tools.data.check.isEmpty(scope.model.inputOnClearAppend)) {
                        scope.model.inputOnClearAppend();
                    }
                };

                /*scope.model.inputOnChoose = scope.model.inputOnChoose || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnChooseAppend)) {
                        scope.model.inputOnChooseAppend();
                    }
                };*/
                if(Tools.data.check.isEmpty(scope.model.inputOnChoose)){
                    scope.model.inputOnChoose = function() {
                        if (!Tools.data.check.isEmpty(scope.model.inputOnChooseAppend)) {
                            scope.model.inputOnChooseAppend();
                        }
                    };
                } else {
                    if(Object.prototype.toString.call(scope.model.inputOnChoose) == "[object Function]"){
                        scope.model.inputOnChoose = scope.model.inputOnChoose;
                    }else if(Object.prototype.toString.call(scope.model.inputOnChoose) == "[object String]"){
                        if(scope.model.inputOnChoose == "INFO_REMINDER"){
                            scope.model.inputOnChoose = function(){
                                    var div =  '<div id="bg">'
                                            +     '<div class="ums-input-warning-card-bg">'
                                            +         '<script type="text/javascript">'
                                            +         ' $("#bg").click(function (event) {$("#bg").remove();})</script>'
                                            +     '</div>'
                                            +     '<div  class="ums-input-warning-card-box">'
                                            +         '<div class="ums-input-warning-card">'
                                            +         '</div>'
                                            +         '<div class="ums-input-warning-card-label">户号在缴费清单上'
                                            +         '</div>'
                                            +       '</div>'
                                            +   '</div>';
                                    $('body').append(div);
                            }
                        }
                    }
                }
                
                scope.model.disabled = scope.model.disabled || false;

                var DIV = '<div ng-show="inputTitleShow" class="ums-input-head">'
                        +     '{{model.inputTitle}}'
                        + '</div>'
                        + '<div class="ums-input-body">'
                        +     '<div ng-show="inputLabelShow" class="ums-input-label">'
                        +         '{{model.inputLabel}}'
                        +     '</div>'
                        +     '<div class="ums-input-value">'
                        +         '<input type="' + typeOfInput + '" ng-model="model.value" ng-disabled="model.disabled"'
                        +             'placeholder="{{model.placeHolder}}" ng-blur="model.inputOnBlur();" '
                        +             'ng-focus="model.inputOnFocus();" ng-keyup="model.inputOnKeyUp();" '
                        +             'ng-keypress="model.inputOnKeyPress();" ng-change="model.inputOnChange();" />'
                        +     '</div>'
                        +     '<div ng-show="tipShow" class="ums-input-tips">'
                        +         '{{model.tips}}'
                        +     '</div>'
                        +     '<div class="ums-input-clear {{clearIconClass}}"'
                        +         'ng-click="model.inputOnClear();">'
                        +     '</div>'
                        +     '<div ng-show="chooseIconShow" class="{{chooseIconClass}}" '
                        +         'ng-click="model.inputOnChoose();">'
                        +     '</div>'
                        + '</div>'
                        + '<div ng-show="inputFootTextShow" class="ums-input-foot">'
                        +     '{{model.inputFootText}}'
                        + '</div>';

                elem.append($compile(DIV)(scope));

//                scope.$watch("model.value", function(newValue) {
//                    if (!Tools.data.check.isEmpty(newValue)) {
//                        // input不为空, 则显示clearIcon
//                        scope.clearIconClass = "ums-input-clear-icon";
//                    } else {
//                        // input为空, 则不显示clearIcon
//                        scope.clearIconClass = "";
//                    }
//                });

                scope.$watch("model.tips", function(newValue) {
                    if (!Tools.data.check.isEmpty(newValue)) {
                        scope.tipShow = true;
                    } else {
                        scope.tipShow = false;
                    }
                });
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-input {{marginTop}}">'
                        + '</div>',
                link: link
            };
        }]);
});