define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-passengers", [])
        .directive("umsPassengers", function() {
            function link(scope, elem, attrs, ctrl) {
                // 最小乘客数
                var minSize = 1;

                // 当前乘客数
                scope.model.curSize = 1;

                // 最大乘客数
                scope.model.maxSize = scope.model.maxSize || 5;

                // 默认至少有一个乘客, 其信息为空
                scope.model.passengerList = [{ticketType: "0", cardType: "0", needSave: false}];

                // 票种
                if (Tools.data.check.isEmpty(scope.model.ticketTypes)) {
                    scope.model.ticketTypes = [{
                        value: "0",
                        text: "成人票"
                    }, {
                        value: "1",
                        text: "儿童票"
                    }, {
                        value: "2",
                        text: "成人携童票"
                    }];
                }

                // 证件类型
                if (Tools.data.check.isEmpty(scope.model.cardTypes)) {
                    scope.model.cardTypes = [{
                        value: "0",
                        text: "身份证"
                    }, {
                        value: "1",
                        text: "护照"
                    }, {
                        value: "2",
                        text: "军官证"
                    }, {
                        value: "3",
                        text: "无证件号（半票）"
                    }];
                }

                // 添加乘客
                scope.model.addPassenger = function() {
                    if (scope.model.curSize < scope.model.maxSize) {
                        scope.model.curSize++;
                        scope.model.passengerList.push({ticketType: "0", cardType: "0", needSave: false});
                    }
                };

                // 删除乘客
                scope.deletePassenger = function(index) {
                    var passenger = scope.model.passengerList[index];

                    // 乘客来自于历史列表
                    if (!Tools.data.check.isEmpty(passenger.hisId)) {
                        // 乘客信息(证件号码唯一)未被修改
                        if (scope.model.hisPassengers[passenger.hisId].cardNo == passenger.cardNo) {
                            // 将历史列表中对应的乘客置为未选中
                            scope.model.hisPassengers[passenger.hisId].checked = false;
                        }
                    }

                    if (scope.model.curSize > minSize) {
                        // 当前乘客数大于1, 从passengerList删掉对应的数组元素
                        scope.model.curSize--;
                        scope.model.passengerList.splice(index, 1);
                    } else {
                        // 当前只有1位乘客, 将其信息置空
                        scope.model.passengerList[0].hisId = "";
                        scope.model.passengerList[0].ticketType = "0";
                        scope.model.passengerList[0].name = "";
                        scope.model.passengerList[0].cardType = "0";
                        scope.model.passengerList[0].cardNo = "";
                        scope.model.passengerList[0].mobileNo = "";
                        scope.model.passengerList[0].needSave = false;
                    }
                };

                scope.checkHisPassenger = function(index) {
                    var passenger = scope.model.hisPassengers[index];

                    if (passenger.checked) { // 乘客被checked
                        var tag = false;

                        // 对passengerList进行遍历
                        for (var i = 0; i < scope.model.curSize; i++) {
                            if (Tools.data.check.isEmpty(scope.model.passengerList[i].name)
                                && Tools.data.check.isEmpty(scope.model.passengerList[i].cardNo)
                                && Tools.data.check.isEmpty(scope.model.passengerList[i].mobileNo)) {
                                // 找到第一个信息为空的乘客, 对其信息进行填充
                                tag = true;

                                scope.model.passengerList[i].hisId = passenger.hisId;
                                scope.model.passengerList[i].ticketType = passenger.ticketType;
                                scope.model.passengerList[i].name = passenger.name;
                                scope.model.passengerList[i].cardType = passenger.cardType;
                                scope.model.passengerList[i].cardNo = passenger.cardNo;
                                scope.model.passengerList[i].mobileNo = passenger.mobileNo;
                                scope.model.passengerList[i].needSave = false;

                                break;
                            }
                        }

                        // 没有找到信息为空的乘客
                        if (!tag) {
                            scope.model.curSize++;

                            // 往passengerList中添加一个乘客
                            scope.model.passengerList.push({
                                "hisId": passenger.hisId,
                                "ticketType": passenger.ticketType,
                                "name": passenger.name,
                                "cardType": passenger.cardType,
                                "cardNo": passenger.cardNo,
                                "mobileNo": passenger.mobileNo,
                                "needSave": false
                            });
                        }
                    } else { // 乘客被unchecked
                        if (scope.model.curSize > minSize) { // 当前乘客数大于最小乘客数
                            // 对passengerList进行遍历
                            for (var i = 0; i < scope.model.curSize; i++) {
                                if (scope.model.passengerList[i].cardNo == passenger.cardNo) {
                                    // 找到passengerList中对应的乘客, 将其删除
                                    scope.model.passengerList.splice(i, 1);

                                    // 当前乘客数减1
                                    scope.model.curSize--;

                                    break;
                                }
                            }
                        } else {
                            // 当前只有一位乘客, 将其信息置空
                            scope.model.passengerList[0].hisId = "";
                            scope.model.passengerList[0].ticketType = "0";
                            scope.model.passengerList[0].name = "";
                            scope.model.passengerList[0].cardType = "0";
                            scope.model.passengerList[0].cardNo = "";
                            scope.model.passengerList[0].mobileNo = "";
                        }
                    }
                };

                // 根据cardType获取对应的cardTypeText
                scope.getTicketTypeText = function(val) {
                    var ticketTypeText = "成人票";

                    for (var i = 0; i < scope.model.ticketTypes.length; i++) {
                        var ticketType = scope.model.ticketTypes[i];

                        if (ticketType.value == val) {
                            ticketTypeText = ticketType.text;
                            break;
                        }
                    }

                    return ticketTypeText;
                };

                // 根据ticketType获取对应的ticketTypeText
                scope.getCardTypeText = function(val) {
                    var cardTypeText = "身份证";

                    for (var i = 0; i < scope.model.cardTypes.length; i++) {
                        var cardType = scope.model.cardTypes[i];

                        if (cardType.value == val) {
                            cardTypeText = cardType.text;
                            break;
                        }
                    }

                    return cardTypeText;
                };

                scope.$watchCollection("model.hisPassengers", function(newVal) {
                    if (!Tools.data.check.isEmpty(scope.model.hisPassengers)) {
                        scope.passengerCheckboxGroupShow = true;

                        for (var i = 0; i < scope.model.hisPassengers.length; i++) {
                            scope.model.hisPassengers[i].hisId = i;
                        }
                    }
                });
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-passengers">'
                        +     '<div ng-show="passengerCheckboxGroupShow" class="ums-passenger-checkbox-group">'
                        +         '<div class="ums-passenger-checkbox-group-title">'
                        +             '常用联系人'
                        +         '</div>'
                        +         '<div class="ums-passenger-checkbox-group-body">'
                        +             '<span class="ums-passenger-checkbox-group-option" '
                        +                 'ng-repeat="passenger in model.hisPassengers">'
                        +                 '<input type="checkbox" ng-model="passenger.checked" '
                        +                     'name="ums-passenger-checkbox" ng-click="checkHisPassenger($index);">'
                        +                 '<span ng-bind="passenger.name></span>'
                        +             '</span>'
                        +         '</div>'
                        +     '</div>'
                        +     '<div class="ums-passenger-list">'
                        +         '<div class="ums-passenger-list-title">'
                        +             '乘客信息'
                        +         '</div>'
                        +         '<div class="ums-passenger-list-body">'
                        +             '<dl class="ums-passenger-info" ng-repeat="passenger in model.passengerList">'
                        +                 '<span class="ums-passenger-info-close" ng-click="deletePassenger($index)">'
                        +                 '</span>'
                        +                 '<dt>'
                        +                     '<span class="ums-passenger-info-label">'
                        +                         '第<span>{{$index + 1}}</span>位'
                        +                     '</span>'
                        +                     '<span class="ums-passenger-info-check">'
                        +                         '<input type="checkbox" ng-model="passenger.needSave">'
                        +                         '<span>保存到常用联系人</span>'
                        +                     '</span>'
                        +                 '</dt>'
                        +                 '<dd>'
                        +                     '<span class="ums-passenger-info-label">票种：</span>'
                        +                     '<div class="ums-passenger-info-select">'
                        +                         '<span>'
                        +                             '{{getTicketTypeText(passenger.ticketType);}}'
                        +                         '</span>'
                        +                         '<select ng-model="passenger.ticketType">'
                        +                             '<option value="{{ticketType.value}}" '
                        +                                 'ng-repeat="ticketType in model.ticketTypes">'
                        +                                 '{{ticketType.text}}'
                        +                             '</option>'
                        +                         '</select>'
                        +                     '</div>'
                        +                 '</dd>'
                        +                 '<dd>'
                        +                     '<span class="ums-passenger-info-label">乘客姓名：</span>'
                        +                     '<p class="ums-passenger-info-input">'
                        +                         '<input type="text" placeholder="请输入姓名" ng-model="passenger.name">'
                        +                     '</p>'
                        +                 '</dd>'
                        +                 '<dd>'
                        +                     '<span class="ums-passenger-info-label">证件类型：</span>'
                        +                     '<div class="ums-passenger-info-select">'
                        +                         '<span>'
                        +                           '{{getCardTypeText(passenger.cardType);}}'
                        +                         '</span>'
                        +                         '<select ng-model="passenger.cardType">'
                        +                             '<option value="{{cardType.value}}" '
                        +                                 'ng-repeat="cardType in model.cardTypes">'
                        +                                 '{{cardType.text}}'
                        +                             '</option>'
                        +                         '</select>'
                        +                     '</div>'
                        +                 '</dd>'
                        +                 '<dd>'
                        +                     '<span class="ums-passenger-info-label">证件号码：</span>'
                        +                     '<p class="ums-passenger-info-input">'
                        +                         '<input type="text" placeholder="请输入号码" ng-model="passenger.cardNo">'
                        +                     '</p>'
                        +                 '</dd>'
                        +                 '<dd>'
                        +                     '<span class="ums-passenger-info-label">手机号码：</span>'
                        +                     '<p class="ums-passenger-info-input">'
                        +                         '<input type="tel" placeholder="请输入号码" ng-model="passenger.mobileNo">'
                        +                     '</p>'
                        +                 '</dd>'
                        +             '</dl>'
                        +         '</div>'
                        +     '</div>'
                        + '</div>',
                link: link
            };
        });
});