define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-password", [])
        .directive("umsPassword", function() {
            function link(scope, elem, attrs, ctrl) {
                // 输入类型
                var inputType = attrs.inputType || scope.model.inputType;
                // 最大长度
                var maxLength = attrs.maxLength || scope.model.maxLength;

                scope.model.inputTitle = attrs.inputTitle || scope.model.inputTitle;
                scope.model.inputLabel = attrs.inputLabel || scope.model.inputLabel;
                scope.model.placeHolder = attrs.placeHolder || scope.model.placeHolder;
                scope.model.tips = attrs.tips || scope.model.tips;

                // inputTitle不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputTitle)) {
                    scope.inputTitleShow = true;
                }

                // inputLabel不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputLabel)) {
                    scope.inputLabelShow = true;
                }

                scope.model.inputOnBlur = scope.model.inputOnBlur || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnBlurAppend)) {
                        scope.model.inputOnBlurAppend();
                    }
                };

                scope.model.inputOnFocus = scope.model.inputOnFocus || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnFocusAppend)) {
                        scope.model.inputOnFocusAppend();
                    }
                };

                scope.model.inputOnKeyUp = scope.model.inputOnKeyUp || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnKeyUpAppend)) {
                        scope.model.inputOnKeyUpAppend();
                    }
                };

                if (inputType == "text") {
                    scope.model.inputOnKeyPress = scope.model.inputOnKeyPress || function() {
                        if (!Tools.data.check.isEmpty(scope.model.inputOnKeyPressAppend)) {
                            scope.model.inputOnKeyPressAppend();
                        }
                    };
                    
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2StringWithLength(
                            scope.model.value, maxLength);

                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                } else if (inputType == "integer") {
                    scope.model.inputOnKeyPress = function(event) {
                        event = event || window.event;

                        var keyCode = event.keyCode || event.which;

                        if (keyCode >= 48 && keyCode <= 57) {
                            event.returnValue = true;
                        } else {
                            event.returnValue = false;
                        }
                        
                        if (!Tools.data.check.isEmpty(scope.model.inputOnKeyPressAppend)) {
                            scope.model.inputOnKeyPressAppend();
                        }
                    };
                    
                    scope.model.inputOnChange = scope.model.inputOnChange || function() {
                        scope.model.value = Tools.data.convert.input2IntegerWithLength(
                            scope.model.value, maxLength);

                        if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                            scope.model.inputOnChangeAppend();
                        }
                    };
                }

                scope.model.inputOnClear = scope.model.inputOnClear || function() {
                    scope.model.value = "";

                    if (!Tools.data.check.isEmpty(scope.model.inputOnClearAppend)) {
                        scope.model.inputOnClearAppend();
                    }
                };

                scope.$watch("model.value", function(newValue) {
                    if (!Tools.data.check.isEmpty(newValue)) {
                        // input不为空, 则显示clearIcon
                        scope.clearIconClass = "ums-password-clear-icon";
                    } else {
                        // input为空, 则不显示clearIcon
                        scope.clearIconClass = "";
                    }
                });

                scope.$watch("model.tips", function(newValue) {
                    if (!Tools.data.check.isEmpty(newValue)) {
                        scope.tipShow = true;
                    } else {
                        scope.tipShow = false;
                    }
                });
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-password">'
                        +     '<div ng-show="inputTitleShow" class="ums-password-head">'
                        +         '{{model.inputTitle}}'
                        +     '</div>'
                        +     '<div class="ums-password-body">'
                        +         '<div ng-show="inputLabelShow" class="ums-password-label">'
                        +             '{{model.inputLabel}}'
                        +         '</div>'
                        +         '<div class="ums-password-value">'
                        +             '<input type="password" ng-model="model.value" '
                        +                 'placeholder="{{model.placeHolder}}" ng-blur="model.inputOnBlur();" '
                        +                 'ng-focus="model.inputOnFocus();" ng-keyup="model.inputOnKeyUp();" '
                        +                 'ng-keypress="model.inputOnKeyPress();" ng-change="model.inputOnChange();" />'
                        +         '</div>'
                        +         '<div ng-show="tipShow" class="ums-password-tips">'
                        +             '{{model.tips}}'
                        +         '</div>'
                        +         '<div class="ums-password-clear {{clearIconClass}}" '
                        +             'ng-click="model.inputOnClear();">'
                        +         '</div>'
                        +     '</div>'
                        + '</div>',
                link: link
            };
        });
});