define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-station-select-group", [])
        .directive("umsStationSelectGroup", ["$timeout", function($timeout) {
            function link(scope, elem, attrs, ctrl) {
                // 出发站列表是否是查找后的
                scope.isStartStationFiltered = false;
                // 到达站列表是否是查找后的
                scope.isStopStationFiltered = false;

                if (Tools.data.check.isEmpty(scope.model.startStationArr)) {
                    scope.startStationListShow = false;
                }

                if (Tools.data.check.isEmpty(scope.model.stopStationArr)) {
                    scope.stopStationListShow = false;
                }

                scope.model.onStationInputFocus = function(id) {
                	if (id == "from") {
                        if (Tools.data.check.isEmpty(scope.model.startStationArr)) {
                            scope.startStationListShow = false;
                        } else {
                            scope.startStationListShow = true;
                        }

                        scope.stopStationListShow = false;
                        
                        if (!Tools.data.check.isEmpty(scope.model.onStartStationInputFocus)) {
                        	scope.model.onStartStationInputFocus();
                		}
                	} else if (id == "to") {
                        scope.startStationListShow = false;

                        scope.model.stopStationArr = scope.model.stopStations;
                        
                        if (Tools.data.check.isEmpty(scope.model.stopStationArr)) {
                            scope.stopStationListShow = false;
                        } else {
                            scope.stopStationListShow = true;
                        }
                        
                        if (!Tools.data.check.isEmpty(scope.model.onStopStationInputFocus)) {
                        	scope.model.onStopStationInputFocus();
                		}
                	}
                };

                scope.model.onStationInputBlur = function(id) {
                    if (id == "from") {
                    	$timeout(function() {
                    		scope.startStationListShow = false;
                    	}, 500);
                    	
                    	if (!Tools.data.check.isEmpty(scope.model.onStartStationInputBlur)) {
                        	scope.model.onStartStationInputBlur();
                		}
                    } else if (id == "to") {
                    	$timeout(function() {
                    		scope.stopStationListShow = false;
                    	}, 500);

                    	if (!Tools.data.check.isEmpty(scope.model.onStopStationInputBlur)) {
                        	scope.model.onStopStationInputBlur();
                		}
                    }
                };

                scope.model.onStationInputChange = function(id) {
                    if (id == "from") {
                        if (!Tools.data.check.isEmpty(scope.model.from)) {
                            scope.model.startStationArr = [];

                            for (var i = 0; i < scope.model.startStations.length; i++) {
                                var startStation = scope.model.startStations[i];

                                if (startStation.name.indexOf(scope.model.from) > -1
                                    || startStation.code.toLowerCase().indexOf(scope.model.from) > -1) {
                                    scope.model.startStationArr.push(startStation);
                                }
                            };

                            scope.isStartStationFiltered = true;
                        } else {
                            scope.model.startStationArr = scope.model.startStations;

                            scope.isStartStationFiltered = false;
                        }

                        if (!Tools.data.check.isEmpty(scope.model.startStationArr)) {
                            scope.startStationListShow = true;
                        } else {
                            scope.startStationListShow = false;
                        }
                    } else if (id == "to") {
                        if (!Tools.data.check.isEmpty(scope.model.to)) {
                            scope.model.stopStationArr = [];

                            for (var i = 0; i < scope.model.stopStations.length; i++) {
                                var stopStation = scope.model.stopStations[i];

                                if (stopStation.name.indexOf(scope.model.to) > -1
                                    || stopStation.code.toLowerCase().indexOf(scope.model.to) > -1) {
                                    scope.model.stopStationArr.push(stopStation);
                                }
                            };

                            scope.isStopStationFiltered = true;
                        } else {
                            scope.model.stopStationArr = scope.model.stopStations;

                            scope.isStopStationFiltered = false;
                        }

                        if (!Tools.data.check.isEmpty(scope.model.stopStationArr)) {
                            scope.stopStationListShow = true;
                        } else {
                            scope.stopStationListShow = false;
                        }
                    }
                };

                scope.model.onStationClick = function(station, id) {
                    if (id == "from") {
                        scope.model.from = station.name;
                        scope.startStationListShow = false;
                        
                        if (!Tools.data.check.isEmpty(scope.model.onStartStationClick)) {
                        	scope.model.onStartStationClick(station);
                        }
                    } else if (id == "to") {
                        scope.model.to = station.name;
                        scope.stopStationListShow = false;
                        
                        if (!Tools.data.check.isEmpty(scope.model.onStopStationClick)) {
                        	scope.model.onStopStationClick(station);
                        }
                    }
                };

                scope.model.exchangeStation = function() {
                    var tmpVal = scope.model.from;
                    scope.model.from = scope.model.to;
                    scope.model.to = tmpVal;
                };

                scope.$watchCollection("model.startStations", function(newVal) {
                    // 出发站
                    scope.model.startStationArr = scope.model.startStations;
                });
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-station-select-group">'
                        +     '<div class="ums-station-select-group-inputs">'
                        +         '<div class="ums-station-to-input">'
                        +             '<div class="ums-station-input-label">目的站：</div>'
                        +             '<div>'
                        +                 '<input type="text" class="ums-station-input-value" ng-model="model.to" '
                        +                     'ng-focus="model.onStationInputFocus(\'to\');" '
                        +                     'ng-blur="model.onStationInputBlur(\'to\');" '
                        +                     'ng-change="model.onStationInputChange(\'to\');"/>'
                        +             '</div>'
                        +         '</div>'
                        +         '<div class="ums-station-from-input">'
                        +             '<div class="ums-station-input-label">出发站:</div>'
                        +             '<div>'
                        +                 '<input type="text" class="ums-station-input-value" ng-model="model.from" '
                        +                     'ng-focus="model.onStationInputFocus(\'from\');" '
                        +                     'ng-blur="model.onStationInputBlur(\'from\');" '
                        +                     'ng-change="model.onStationInputChange(\'from\');"/>'
                        +             '</div>'
                        +         '</div>'
                        +         '<div class="ums-station-exchange-btn" ng-click="model.exchangeStation();"></div>'
                        +     '</div>'
                        +     '<ul ng-show="startStationListShow" ng-class="{true:\'ums-station-list-filter\', '
                        +         'false:\'ums-station-list-all\'}[isStartStationFiltered]">'
                        +         '<li ng-repeat="station in model.startStationArr">'
                        +             '<a href="javascript:void(0);" ng-click="model.onStationClick(station, \'from\');">'
                        +                 '{{station.name}}'
                        +             '</a>'
                        +         '</li>'
                        +     '</ul>'
                        +     '<ul ng-show="stopStationListShow" ng-class="{true:\'ums-station-list-filter\', '
                        +         'false:\'ums-station-list-all\'}[isStopStationFiltered]">'
                        +         '<li ng-repeat="station in model.stopStationArr">'
                        +             '<a href="javascript:void(0);" ng-click="model.onStationClick(station, \'to\');">'
                        +                 '{{station.name}}'
                        +             '</a>'
                        +         '</li>'
                        +     '</ul>'
                        + '</div>',
                link: link
            };
        }]);
});