define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-tel-input", [])
        .directive("umsTelInput", function() {
            function link(scope, elem, attrs, ctrl) {
            	// 是否为页面中的第一个元素
                var isTop = false;
                
                if (!Tools.data.check.isEmpty(attrs.isTop)) {
                    if (typeof(attrs.isTop) == "string") {
                    	isTop = (attrs.isTop == "true") || !(attrs.isTop == "false");
                    } else if (typeof(attrs.isTop) == "boolean") {
                    	isTop = attrs.isTop;
                    }
                } else {
                    if (typeof(scope.model.isTop) == "string") {
                    	isTop = (scope.model.isTop == "true") || !(scope.model.isTop == "false");
                    } else if (typeof(scope.model.isTop) == "boolean") {
                    	isTop = scope.model.isTop;
                    }
                }
                
            	// 整数的最大长度
            	var intLength = attrs.intLength || scope.model.intLength || 11;
                // 分隔长度
                var splitLength = attrs.splitLength || scope.model.splitLength || 4;
                var firstSplitLength = attrs.firstSplitLength || scope.model.firstSplitLength || 3;

                scope.model.inputTitle = attrs.inputTitle || scope.model.inputTitle;
                scope.model.inputLabel = attrs.inputLabel || scope.model.inputLabel;
                scope.model.placeHolder = attrs.placeHolder || scope.model.placeHolder;
                scope.model.tips = attrs.tips || scope.model.tips;

                // inputTitle不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputTitle)) {
                    scope.inputTitleShow = true;
                }

                // 页面中的第一个元素, 而且title不为空, 则将margin-top设为0
                if (isTop && scope.inputTitleShow) {
                	scope.marginTop = "margin-top-0";
                }
                
                // inputLabel不为空, 则显示
                if (!Tools.data.check.isEmpty(scope.model.inputLabel)) {
                    scope.inputLabelShow = true;
                }

                scope.model.inputOnBlur = scope.model.inputOnBlur || function() {
                    if (!Tools.data.check.isEmpty(scope.model.value)
                        && scope.model.value.length == intLength) {
                        scope.model.value = Tools.data.format.stringWithSpace(
                            scope.model.value, splitLength, firstSplitLength);
                    }

                    if (!Tools.data.check.isEmpty(scope.model.inputOnBlurAppend)) {
                        scope.model.inputOnBlurAppend();
                    }
                };

                scope.model.inputOnFocus = scope.model.inputOnFocus || function() {
                    scope.model.value = Tools.data.convert.trim(scope.model.value);

                    if (!Tools.data.check.isEmpty(scope.model.inputOnFocusAppend)) {
                        scope.model.inputOnFocusAppend();
                    }
                };

                scope.model.inputOnKeyUp = scope.model.inputOnKeyUp || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnKeyUpAppend)) {
                        scope.model.inputOnKeyUpAppend();
                    }
                };

                scope.model.inputOnChange = scope.model.inputOnChange || function() {
                    scope.model.value = Tools.data.convert.input2IntegerWithLength(
                        scope.model.value, intLength);

                    if (!Tools.data.check.isEmpty(scope.model.inputOnChangeAppend)) {
                        scope.model.inputOnChangeAppend();
                    }
                };

                scope.model.inputOnClear = scope.model.inputOnClear || function() {
                    scope.model.value = "";
                    scope.model.tips = "";

                    if (!Tools.data.check.isEmpty(scope.model.inputOnClearAppend)) {
                        scope.model.inputOnClearAppend();
                    }
                };

                scope.model.inputOnChoose = scope.model.inputOnChoose || function() {
                    if (!Tools.data.check.isEmpty(scope.model.inputOnChooseAppend)) {
                        scope.model.inputOnChooseAppend();
                    }
                };

                scope.model.fillPhoneNum = scope.model.fillPhoneNum || function(number, name) {
                    if (!Tools.data.check.isEmpty(scope.model.fillPhoneNumAppend)) {
                        scope.model.fillPhoneNumAppend(number, name);
                    }
                };

                scope.$watch("model.value", function(newValue) {
                    if (!Tools.data.check.isEmpty(newValue)) {
                    	newValue = Tools.data.convert.trim(newValue);
                        
                    	if (newValue.length == intLength) {
                            scope.clearIconShow = false;
                            scope.chooseIconShow = true;
                        } else {
                            scope.clearIconShow = true;
                            scope.chooseIconShow = false;
                        }
                    } else {
                        scope.clearIconShow = false;
                        scope.chooseIconShow = true;
                    }
                });

                scope.$watch("model.tips", function(newValue) {
                    if (!Tools.data.check.isEmpty(newValue)) {
                        scope.tipShow = true;
                    } else {
                        scope.tipShow = false;
                    }
                });
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-tel-input {{marginTop}}">'
                        +     '<div ng-show="inputTitleShow" class="ums-tel-input-head" ng-bind="model.inputTitle">'
                        +     '</div>'
                        +     '<div class="ums-tel-input-body">'
                        +         '<div ng-show="inputLabelShow" class="ums-tel-input-label" ng-bind="model.inputLabel">'
                        +         '</div>'
                        +         '<div class="ums-tel-input-value">'
                        +             '<input type="tel" ng-model="model.value" placeholder="{{model.placeHolder}}"'
                        +                 'ng-blur="model.inputOnBlur();" ng-focus="model.inputOnFocus();"'
                        +                 'ng-keyup="model.inputOnKeyUp();" ng-change="model.inputOnChange();" />'
                        +         '</div>'
                        +         '<div ng-show="tipShow" class="ums-tel-input-tips" ng-bind="model.tips">'
                        +         '</div>'
                        +         '<div ng-show="clearIconShow" class="ums-tel-input-clear" '
                        +             'ng-click="model.inputOnClear();">'
                        +         '</div>'
                        +         '<div ng-show="chooseIconShow" class="ums-tel-input-choose" '
                        +             'ng-click="model.inputOnChoose();">'
                        +         '</div>'
                        +     '</div>'
                        +     '<ul class="ums-tel-input-result">'
                        +         '<li ng-repeat="contact in model.contacts | filter : model.value" '
                        +             'ng-click="model.fillPhoneNum(contact.phoneNumber, contact.userName)">'
                        +             '<span ng-bind="contact.phoneNumber"></span>'
                        +             '<span ng-bind="contact.userName"></span>'
                        +         '</li>'
                        +     '</ul>'
                        + '</div>',
                link: link
            };
        });
});