define(["angular", "tool"], function () {
    "use strict";
    return angular.module("ums-ticket-calendar", [])
        .directive("umsTicketCalendar", ["$compile", function($compile) {
            function link(scope, elem, attrs, ctrl) {
                scope.model.limitDays = scope.model.limitDays || 5;

                var days = ["星期天", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六"];

                var today = new Date();

                scope.setValue = function(value) {
                    value = value + "";

                    var year = value.substring(0, 4);
                    var month = value.substring(4, 6);
                    var date = value.substring(6, 8);

                    var objDate = new Date(year, month - 1, date);

                    var day = objDate.getDay();

                    scope.model.value = value;

                    scope.year = year;
                    scope.month = month;
                    scope.date = date;
                    scope.day = days[day];

                    scope.ticketCalendarBoxShow = false;
                };

                scope.setYearAndMonth = function() {
                    var year = today.getFullYear();
                    var month = today.getMonth() + 1;

                    return year + "年" + month + "月";
                };

                (function() {
                    scope.setValue(getToday());

                    // 今天
                    var intToday = parseInt(getToday());

                    // 可以购票的最后一天
                    var intLastDateCanBuy = parseInt(getLastDateCanBuy());

                    // 当月的第一天
                    var firstDateOfMonth = new Date(today.getFullYear(), today.getMonth(), 1);

                    // 当月第一天星期几
                    var firstDayOfWeek = firstDateOfMonth.getDay();

                    if (firstDayOfWeek == 0) {
                        firstDayOfWeek = 7;
                    }

                    // 当月的最后一天
                    var lastDateOfMonth = getLastDateOfMonth();

                    var t = 0;
                    var nn = 0;
                    var nul = 0;

                    var tabFullYear = today.getFullYear();
                    var tabMonth = formatNum(today.getMonth() + 1);

                    var dateTRs = '';

                    for (var i = 1; i <= firstDayOfWeek + lastDateOfMonth; i++) {
                        if (i >= firstDayOfWeek) {
                            t++;
                        }

                        var tabDate = parseInt(tabFullYear + '' + tabMonth + '' + formatNum(t));

                        var tr = '';

                        if (i % 7 == 1) {
                            tr += '<tr>';
                        }

                        var isWeekend = false;
                        var className = "";
                        var textName = "";

                        // 星期六, 星期日
                        if (i % 7 == 0 || i % 7 == 6) {
                            isWeekend = true;
                        }

                        if (t > 0) {
                            if (t <= lastDateOfMonth) {
                                nn = t;

                                // 小于当前时间或者大于limitDays以后, 颜色设置成淡黄色
                                if (tabDate < intToday || tabDate >= intLastDateCanBuy) {
                                    className = isWeekend ? "ums-ticket-calendar-weekend" : "ums-ticket-calendar-out";
                                    tr += '<td class="' + className + '">'
                                       +      '<a style="color:#cfd1d2" href="javascript:void(0)">' + t + '</a>'
                                       +  '</td>';
                                } else {
                                    if (tabDate == intToday) {
                                        className = isWeekend ? "ums-ticket-calendar-today ums-ticket-calendar-weekend ums-ticket-calendar-in"
                                            : "ums-ticket-calendar-today ums-ticket-calendar-in";
                                        textName = '今天';
                                    } else {
                                        className = isWeekend ? "ums-ticket-calendar-weekend ums-ticket-calendar-in" : "ums-ticket-calendar-in";
                                        textName = t;
                                    }

                                    tr += '<td class="' + className + '" ng-click="setValue(' + tabDate + ')">'
                                       +      '<a href="javascript:void(0)">' + textName + '</a>'
                                       +  '</td>';
                                }
                            }
                        } else {
                            nul++;
                            className = isWeekend ? "ums-ticket-calendar-weekend" : "ums-ticket-calendar-out";
                            tr += '<td class="' + className + '">'
                               +      '<a href="javascript:void(0)"></a>'
                               +  '</td>';
                        }

                        if (i % 7 == 0) {
                            tr += '</tr>';
                        }

                        dateTRs += tr;
                    }

                    // 填补空的TD
                    var nulId = 7 - (nul + nn) % 7;

                    if (nulId == 7) nulId = 0;

                    var weekend = nulId - 2;

                    for (var r = 0; r < nulId; r++) {
                        if (r >= weekend) {
                            tr += '<td class="ums-ticket-calendar-weekend">&nbsp;</td>';
                        } else {
                            tr += '<td class="ums-ticket-calendar-out">&nbsp;</td>';
                        }
                    }

                    if (nulId == 0) {
                        tr += '</tr>';
                    }

                    dateTRs += tr;

                    elem.children().eq(1).children().eq(2).children().eq(0).append($compile(dateTRs)(scope));
                })();

                /**
                 * 获取可以购票的最后一天
                 * @returns {string}
                 */
                function getLastDateCanBuy() {
                    var LastDateCanBuy = new Date();

                    LastDateCanBuy.setDate(LastDateCanBuy.getDate() + scope.model.limitDays);

                    var year = LastDateCanBuy.getFullYear();
                    var month = LastDateCanBuy.getMonth() + 1;
                    var date = LastDateCanBuy.getDate();

                    return year + '' + formatNum(month) + '' + formatNum(date);
                };

                /**
                 * 获取当月的最后一天
                 * @returns {number}
                 */
                function getLastDateOfMonth() {
                    var lastDateOfMonth = new Date(today.getFullYear(), today.getMonth() + 1, 0);
                    return lastDateOfMonth.getDate();
                };

                /**
                 * 获取今天的日期, 格式: yyyyMMdd
                 * @returns {string}
                 */
                function getToday() {
                    var year = today.getFullYear();
                    var month = today.getMonth() + 1;
                    var date = today.getDate();
                    return year + '' + formatNum(month) + '' + formatNum(date);
                };

                /**
                 * 数字小于9, 则在前面补0
                 * @param num
                 * @returns {*}
                 */
                function formatNum(num) {
                    return num > 9 ? num : '0' + num;
                }
            }

            return {
                restrict: "E",
                replace: true,
                scope: {
                    model: "="
                },
                template: '<div class="ums-ticket-calendar">'
                        +     '<div class="ums-ticket-calendar-line">'
                        +         '<div class="ums-ticket-calendar-label">'
                        +             '<span>出发日期:</span>'
                        +         '</div>'
                        +         '<div class="ums-ticket-calendar-text" ng-click="ticketCalendarBoxShow = !ticketCalendarBoxShow">'
                        +             '<a>{{year}}年<span>{{month}}月{{date}}日</span>{{day}}</a>'
                        +         '</div>'
                        +     '</div>'
                        +     '<div ng-show="ticketCalendarBoxShow" class="ums-ticket-calendar-box">'
                        +         '<div class="ums-ticket-calendar-box-head">'
                        +             '<h2>{{setYearAndMonth();}}</h2>'
                        +         '</div>'
                        +         '<table class="ums-ticket-calendar-box-table1">'
                        +             '<thead>'
                        +                 '<tr>'
                        +                     '<th>周一</th>'
                        +                     '<th>周二</th>'
                        +                     '<th>周三</th>'
                        +                     '<th>周四</th>'
                        +                     '<th>周五</th>'
                        +                     '<th><span>周六</span></th>'
                        +                     '<th><span>周日</span></th>'
                        +                 '</tr>'
                        +             '</thead>'
                        +         '</table>'
                        +         '<table class="ums-ticket-calendar-box-table2">'
                        +             '<tbody id="ums-ticket-calendar-box-table2-tbody">'
                        +             '</tbody>'
                        +         '</table>'
                        +     '</div>'
                        + '</div>',
                link: link
            };
        }]);
});